==> refdb-0.9.5a.tar.gz: refdb-0.9.5/src/writeris.c <==
/* writeris.c: functions to write RIS datasets and to create DocBook bibliography entries */
/* markus@mhoenicka.de 4-28-00 */
/* $Id: writeris.c,v 1.12 2003/08/30 21:23:19 mhoenicka Exp $ */

/*
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/


#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <string.h>
#include <dbi/dbi.h>

#include "refdb.h"
#include "linklist.h"
#include "refdbd.h" /* depends on dbi.h */
#include "backend.h"
#include "writeris.h" 
#include "strfncs.h"
#include "backend-scrn.h"
#include "backend-ris.h"
#include "backend-risx.h"
#include "backend-db31.h"
#include "backend-teix.h"
#include "backend-bibtex.h" /* depends on refdbd.h */
#include "backend-html.h"
#include "backend-dbib.h"

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  render_ref(): formats the result of a query

  char* render_ref returns ptr to the buffer if successful, NULL if failed

  struct renderinfo* ptr_rendinfo ptr to a structure with the info
                             how the reference should be rendered

 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
char* render_ref(struct renderinfo* ptr_rendinfo) {
  char* new_ref;

  if (ptr_rendinfo->ref_format == REFRIS || ptr_rendinfo->ref_format == REFCGIRIS) { /* RIS or cgi-ris*/
    new_ref = render_ris(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == RISX) { /* RISX */
    new_ref = render_risx(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFDOCBK
	   || ptr_rendinfo->ref_format == REFDOCBKX) { /* DocBook */
    new_ref = render_db31(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFTEIX) { /* TEI XML */
    new_ref = render_teix(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFBIBTEX) { /* bibtex */
    new_ref = render_bibtex(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFHTML
	   || ptr_rendinfo->ref_format == REFXHTML
	   || ptr_rendinfo->ref_format == REFCGIHTML) { /* (x)html or cgi*/
    new_ref = render_html(ptr_rendinfo);
  }
  else { /* screen output; make this default, just in case */
    new_ref = render_scrn(ptr_rendinfo);
  }
  
  if (new_ref) {
    *(ptr_rendinfo->ptr_ref) = new_ref;
    return new_ref;
  }
  else {
    return NULL;
  }
}

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  prepare_render(): writes a header for the output of a query

  char* prepare_render returns a ptr to the modified string if
                       successful, NULL if failed

  struct renderinfo* ptr_rendinfo ptr to a structure with the info
                             how the reference should be rendered

 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
char* prepare_render(struct renderinfo* ptr_rendinfo) {
  if (ptr_rendinfo->ref_format == REFRIS || ptr_rendinfo->ref_format == REFCGIRIS) {
    return prepare_render_ris(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFDOCBK
	   || ptr_rendinfo->ref_format == REFDOCBKX) {
    prepare_render_db31(ptr_rendinfo);
    return *(ptr_rendinfo->ptr_ref);
  }
  else if (ptr_rendinfo->ref_format == RISX) { /* RISX */
    prepare_render_risx(ptr_rendinfo);
    return *(ptr_rendinfo->ptr_ref);
  }
  else if (ptr_rendinfo->ref_format == REFTEIX) { /* TEI XML */
    prepare_render_teix(ptr_rendinfo);
    return *(ptr_rendinfo->ptr_ref);
  }
  else if (ptr_rendinfo->ref_format == REFBIBTEX) {
    prepare_render_bibtex(ptr_rendinfo);
    return *(ptr_rendinfo->ptr_ref);
  }
  else if (ptr_rendinfo->ref_format == REFHTML       /* plain html/xhtml */
	   || ptr_rendinfo->ref_format == REFXHTML   /* or html via cgi */
	   || ptr_rendinfo->ref_format == REFCGIHTML) { 
    return prepare_render_html(ptr_rendinfo);
  }
  else { /* default */
    prepare_render_scrn(ptr_rendinfo);
    return *(ptr_rendinfo->ptr_ref);
  }
}

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  finish_render(): writes a footer for the output of a query

  char* finish_render returns ptr to the buffer if successful, NULL if failed

  struct renderinfo* ptr_rendinfo ptr to a structure with the info
                             how the reference should be rendered

 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
char* finish_render(struct renderinfo* ptr_rendinfo) {
  char* new_ref;

  if(ptr_rendinfo->ref_format == REFRIS || ptr_rendinfo->ref_format == REFCGIRIS) {
    if ((new_ref = finish_render_ris(ptr_rendinfo)) == NULL) {
      return NULL;
    }
    else {
      *(ptr_rendinfo->ptr_ref) = new_ref;
    }
  }
  else if(ptr_rendinfo->ref_format == REFDOCBK
	  || ptr_rendinfo->ref_format == REFDOCBKX) {
    if ((new_ref = finish_render_db31(ptr_rendinfo)) == NULL) {
      return NULL;
    }
    else {
      *(ptr_rendinfo->ptr_ref) = new_ref;
    }
  }
  else if(ptr_rendinfo->ref_format == REFTEIX) {
    if ((new_ref = finish_render_teix(ptr_rendinfo)) == NULL) {
      return NULL;
    }
    else {
      *(ptr_rendinfo->ptr_ref) = new_ref;
    }
  }
  else if(ptr_rendinfo->ref_format == RISX) {
    if ((new_ref = finish_render_risx(ptr_rendinfo)) == NULL) {
      return NULL;
    }
    else {
      *(ptr_rendinfo->ptr_ref) = new_ref;
    }
  }
  else if(ptr_rendinfo->ref_format == REFBIBTEX) {
    if ((new_ref = finish_render_bibtex(ptr_rendinfo)) == NULL) {
      return NULL;
    }
    else {
      *(ptr_rendinfo->ptr_ref) = new_ref;
    }
  }
  else if (ptr_rendinfo->ref_format == REFHTML
	   || ptr_rendinfo->ref_format == REFXHTML
	   || ptr_rendinfo->ref_format == REFCGIHTML) { /* html or cgi */
    if ((new_ref = finish_render_html(ptr_rendinfo)) == NULL) {
      return NULL;
    }
    else {
      *(ptr_rendinfo->ptr_ref) = new_ref;
    }
  }
  else if (ptr_rendinfo->ref_format != 5) { /* default */
    if ((new_ref = finish_render_scrn(ptr_rendinfo)) == NULL) {
      return NULL;
    }
    else {
      *(ptr_rendinfo->ptr_ref) = new_ref;
    }
  }
  return *(ptr_rendinfo->ptr_ref);
}

==> refdb-0.9.6.tar.gz: refdb-0.9.6/src/writeris.c <==
/* writeris.c: functions to write RIS datasets and to create DocBook bibliography entries */
/* markus@mhoenicka.de 4-28-00 */
/* $Id: writeris.c,v 1.12.2.1 2005/04/15 22:45:11 mhoenicka Exp $ */

/*
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/


#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <string.h>
#include <dbi/dbi.h>

#include "refdb.h"
#include "linklist.h"
#include "refdbd.h" /* depends on dbi.h */
#include "backend.h"
#include "writeris.h" 
#include "strfncs.h"
#include "backend-scrn.h"
#include "backend-ris.h"
#include "backend-risx.h"
#include "backend-db31.h"
#include "backend-teix.h"
#include "backend-bibtex.h" /* depends on refdbd.h */
#include "backend-html.h"
#include "backend-dbib.h"

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  render_ref(): formats the result of a query

  int render_ref returns 0 if successful, > 0 if failed

  struct renderinfo* ptr_rendinfo ptr to a structure with the info
                             how the reference should be rendered

 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
int render_ref(struct renderinfo* ptr_rendinfo) {
  int retval;

  if (ptr_rendinfo->ref_format == REFRIS || ptr_rendinfo->ref_format == REFCGIRIS) { /* RIS or cgi-ris*/
    retval = render_ris(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == RISX) { /* RISX */
    retval = render_risx(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFDOCBK
	   || ptr_rendinfo->ref_format == REFDOCBKX) { /* DocBook */
    retval = render_db31(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFTEIX) { /* TEI XML */
    retval = render_teix(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFBIBTEX) { /* bibtex */
    retval = render_bibtex(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFHTML
	   || ptr_rendinfo->ref_format == REFXHTML
	   || ptr_rendinfo->ref_format == REFCGIHTML) { /* (x)html or cgi*/
    retval = render_html(ptr_rendinfo);
  }
  else { /* screen output; make this default, just in case */
    retval = render_scrn(ptr_rendinfo);
  }

  return retval;
}

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  prepare_render(): writes a header for the output of a query

  int prepare_render returns 0 if successful, > 0 if failed

  struct renderinfo* ptr_rendinfo ptr to a structure with the info
                             how the reference should be rendered

 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
int prepare_render(struct renderinfo* ptr_rendinfo) {
  int retval;
  if (ptr_rendinfo->ref_format == REFRIS || ptr_rendinfo->ref_format == REFCGIRIS) {
    retval = prepare_render_ris(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFDOCBK
	   || ptr_rendinfo->ref_format == REFDOCBKX) {
    retval = prepare_render_db31(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == RISX) { /* RISX */
    retval = prepare_render_risx(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFTEIX) { /* TEI XML */
    retval = prepare_render_teix(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFBIBTEX) {
    retval = prepare_render_bibtex(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFHTML       /* plain html/xhtml */
	   || ptr_rendinfo->ref_format == REFXHTML   /* or html via cgi */
	   || ptr_rendinfo->ref_format == REFCGIHTML) { 
    retval = prepare_render_html(ptr_rendinfo);
  }
  else { /* default */
    retval = prepare_render_scrn(ptr_rendinfo);
  }

  return retval;
}

/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  finish_render(): writes a footer for the output of a query

  int finish_render returns 0 if successful, > 0 if failed

  struct renderinfo* ptr_rendinfo ptr to a structure with the info
                             how the reference should be rendered

 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
int finish_render(struct renderinfo* ptr_rendinfo) {
  int retval;

  if(ptr_rendinfo->ref_format == REFRIS || ptr_rendinfo->ref_format == REFCGIRIS) {
    retval = finish_render_ris(ptr_rendinfo);
  }
  else if(ptr_rendinfo->ref_format == REFDOCBK
	  || ptr_rendinfo->ref_format == REFDOCBKX) {
    retval = finish_render_db31(ptr_rendinfo);
  }
  else if(ptr_rendinfo->ref_format == REFTEIX) {
    retval = finish_render_teix(ptr_rendinfo);
  }
  else if(ptr_rendinfo->ref_format == RISX) {
    retval = finish_render_risx(ptr_rendinfo);
  }
  else if(ptr_rendinfo->ref_format == REFBIBTEX) {
    retval = finish_render_bibtex(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format == REFHTML
	   || ptr_rendinfo->ref_format == REFXHTML
	   || ptr_rendinfo->ref_format == REFCGIHTML) { /* html or cgi */
    retval = finish_render_html(ptr_rendinfo);
  }
  else if (ptr_rendinfo->ref_format != 5) { /* default */
    retval = finish_render_scrn(ptr_rendinfo);
  }

  return retval;
}
